@@ -11,7 +11,7 @@ from django import forms
 class DepartmentForms(forms.Form):
     name = forms.CharField(min_length=2, max_length=32)
     charger_id = forms.IntegerField(required=False)
-    parent_id = forms.IntegerField()
+    parent_id = forms.IntegerField(required=False)
     organization_id = forms.IntegerField()
 
 
