@@ -70,6 +70,7 @@ class Department(BaseModel):
                 "id": i.id,
                 "name": i.name,
                 "charger_id": i.charger_id,
+                "path_name": [Department.objects.get(pk=id_).name for id_ in i.path + [i.id]],
                 "path": i.path,
                 "show_order": i.show_order,
             }
@@ -84,6 +85,7 @@ class Department(BaseModel):
             "id": self.id,
             "name": self.name,
             "charger_id": self.charger_id,
+            "path_name": [self.name],
             "path": [],
             "show_order": self.show_order,
             "children": child_map.get(str(self.id), []),
