@@ -366,8 +366,79 @@ def mv_show_order(organization_id: int, data: dict):
     return Resp()
 
 
-def get_all_chargers(organization_id):
+def get_all_chargers(organization_id: int):
     return Resp(data=list(DepartmentUserMap.objects.filter(
         department__organization_id=organization_id,
     ).order_by("user_id").values_list("user_id", flat=True)))
 
+
+def get_organization_users(organization_id: int):
+    """
+    获取组织下所有的用户
+    :param organization_id:
+    :return:
+    """
+    user_ids = DepartmentUserMap.objects.filter(
+        department__organization_id=organization_id
+    ).values_list("user_id", flat=True)
+    return Resp(data=list(user_ids))
+
+
+def exclude_department_users(organization_id: int, department_id: int):
+    """
+    获取企业中除了这个部门中用户的其他用户
+    :param organization_id:
+    :param department_id:
+    :return:
+    """
+    organization_users = get_organization_users(organization_id)
+    if not organization_users["code"] == 200:
+        return Resp(code=ServerErrorCode, msg=f"{organization_users['msg']}")
+    department_users = get_department_user(organization_id, department_id)
+    if not department_users["code"] == 200:
+        return Resp(code=ServerErrorCode, msg=f"{department_users['msg']}")
+
+    all_users = set(organization_users["data"])
+    excluded_users = set(department_users["data"])
+    if not excluded_users.issubset(all_users):
+        return Resp(code=ServerErrorCode, msg=f"excluded users aren't subset of all users")
+    users = all_users.difference(excluded_users)
+    return Resp(data=list(users))
+
+
+@transaction.atomic
+def user_change_department(organization_id: int, user_id: int, department_ids: list):
+    """
+    用户变更部门
+    :param organization_id:
+    :param user_id:
+    :param department_ids:
+    :return:
+    """
+    try:
+        DepartmentUserMap.objects.filter(
+            department__organization_id=organization_id,
+            user_id=user_id
+        ).delete()
+
+        changed_instance_list = [DepartmentUserMap(department_id=id_, user_id=user_id) for id_ in department_ids]
+        DepartmentUserMap.objects.bulk_create(changed_instance_list)
+        return Resp()
+    except Exception as e:
+        raise Exception(str(e))
+
+
+def get_user_departments(organization_id: int, user_id: int):
+    """
+    获取用户所在的部门
+    :param organization_id:
+    :param user_id:
+    :return:
+    """
+    user_departments = DepartmentUserMap.objects.filter(
+        department__organization_id=organization_id,
+        user_id=user_id
+    ).values_list("department_id", flat=True)
+
+    return Resp(data=list(user_departments))
+
