@@ -20,7 +20,7 @@ from departments.utils.department_funcs import (
     get_department_user,
     delete_department_user_map,
     mv_show_order,
-    get_all_chargers
+    get_all_chargers, get_organization_users, exclude_department_users, user_change_department, get_user_departments
 )
 
 
@@ -31,9 +31,24 @@ class DepartmentViewSet(object):
             raise TypeError(f"organization_id is failed type ")
         self.organization_id = organization_id
 
+    def organization_user_list(self):
+        """
+        获取当前组织下所有的用户
+        :return:
+        """
+        return get_organization_users(self.organization_id)
+
     def retrieve(self, pk: int):
         return get_department_object(self.organization_id, pk)
 
+    def exclude(self, department_id: int):
+        """
+        获取除了 department_id 这个部门的用户
+        :param department_id: 部门id
+        :return:
+        """
+        return exclude_department_users(self.organization_id, department_id)
+
     def list(self, type_: str, department_id: int = None, department_name: str = None):
         """
         获取部门列表.有两种方式. 1: 一次性获取; 2: 获取下一级部门.
@@ -47,7 +62,7 @@ class DepartmentViewSet(object):
         elif type_ == "sub":
             return get_sub_department(self.organization_id, department_id)
         else:
-            return Resp(code=ServerErrorCode, msg="error", data="failed params")
+            return Resp(code=ServerErrorCode, msg="failed params")
 
     def create(self, data: dict):
         """
@@ -56,18 +71,27 @@ class DepartmentViewSet(object):
         :return:
         """
         data["organization_id"] = self.organization_id
-        return create_department(data)
+        try:
+            return create_department(data)
+        except Exception as err:
+            return Resp(code=ServerErrorCode, msg=str(err),)
 
     def update(self, pk: int, data: dict):
         data["organization_id"] = self.organization_id
         try:
             return update_department(pk, data)
         except Exception as err:
-            return Resp(code=ServerErrorCode, msg="error", data=str(err))
+            return Resp(code=ServerErrorCode, msg=str(err))
 
     def delete(self, pk: int):
         return delete_department(self.organization_id, pk)
 
+    def change(self, user_id: int, department_ids: list):
+        try:
+            return user_change_department(self.organization_id, user_id, department_ids)
+        except Exception as err:
+            return Resp(code=ServerErrorCode, msg=str(err))
+
     @transaction.atomic
     def move_show_order(self, data: dict):
         """
@@ -78,6 +102,14 @@ class DepartmentViewSet(object):
         """
         return mv_show_order(self.organization_id, data)
 
+    def user_departments(self, user_id: int):
+        """
+        获取用户下的部门
+        :param user_id:
+        :return:
+        """
+        return get_user_departments(self.organization_id, user_id)
+
     # def department_user_list(self, department_id: int, page: int = 1, size: int = 20):
     def department_user_list(self, department_id: int, page: int = 1, size: int = 20):
         """
@@ -100,7 +132,7 @@ class DepartmentViewSet(object):
         try:
             return add_department_user_map(self.organization_id, department_id, user_ids)
         except Exception as err:
-            return Resp(code=BadRequestCode, msg="error", data=str(err))
+            return Resp(code=BadRequestCode, msg=str(err))
 
     def delete_department_user(self, department_id: int, user_ids: list):
         """
